==> qpid-proton-0.36.0-3-aarch64.pkg.tar.xz: usr/lib/cmake/Proton/ProtonTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Proton::qpid-proton" for configuration "RelWithDebInfo"
set_property(TARGET Proton::qpid-proton APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Proton::qpid-proton PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libqpid-proton.so.11.14.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libqpid-proton.so.11"
  )

list(APPEND _IMPORT_CHECK_TARGETS Proton::qpid-proton )
list(APPEND _IMPORT_CHECK_FILES_FOR_Proton::qpid-proton "${_IMPORT_PREFIX}/lib/libqpid-proton.so.11.14.1" )

# Import target "Proton::core" for configuration "RelWithDebInfo"
set_property(TARGET Proton::core APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Proton::core PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libqpid-proton-core.so.10.12.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libqpid-proton-core.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS Proton::core )
list(APPEND _IMPORT_CHECK_FILES_FOR_Proton::core "${_IMPORT_PREFIX}/lib/libqpid-proton-core.so.10.12.1" )

# Import target "Proton::proactor" for configuration "RelWithDebInfo"
set_property(TARGET Proton::proactor APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Proton::proactor PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libqpid-proton-proactor.so.1.8.2"
  IMPORTED_SONAME_RELWITHDEBINFO "libqpid-proton-proactor.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS Proton::proactor )
list(APPEND _IMPORT_CHECK_FILES_FOR_Proton::proactor "${_IMPORT_PREFIX}/lib/libqpid-proton-proactor.so.1.8.2" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> qpid-proton-0.37.0-2-aarch64.pkg.tar.xz: usr/lib/cmake/Proton/ProtonTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Proton::qpid-proton" for configuration "RelWithDebInfo"
set_property(TARGET Proton::qpid-proton APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Proton::qpid-proton PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libqpid-proton.so.11.15.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libqpid-proton.so.11"
  )

list(APPEND _cmake_import_check_targets Proton::qpid-proton )
list(APPEND _cmake_import_check_files_for_Proton::qpid-proton "${_IMPORT_PREFIX}/lib/libqpid-proton.so.11.15.0" )

# Import target "Proton::core" for configuration "RelWithDebInfo"
set_property(TARGET Proton::core APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Proton::core PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libqpid-proton-core.so.10.13.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libqpid-proton-core.so.10"
  )

list(APPEND _cmake_import_check_targets Proton::core )
list(APPEND _cmake_import_check_files_for_Proton::core "${_IMPORT_PREFIX}/lib/libqpid-proton-core.so.10.13.0" )

# Import target "Proton::proactor" for configuration "RelWithDebInfo"
set_property(TARGET Proton::proactor APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Proton::proactor PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libqpid-proton-proactor.so.1.8.3"
  IMPORTED_SONAME_RELWITHDEBINFO "libqpid-proton-proactor.so.1"
  )

list(APPEND _cmake_import_check_targets Proton::proactor )
list(APPEND _cmake_import_check_files_for_Proton::proactor "${_IMPORT_PREFIX}/lib/libqpid-proton-proactor.so.1.8.3" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
